% DIPOLE ARRAY NEAR FIELD (exdipoles)
% 
% Example using the plot_field_slice1.m function to plot E-field (V/m)
%
% In this case two 1GHz dipoles are placed 2*lambda apart on the x-y plane.
% The waves propagating from each dipole interfere with each other, causing 
% regions of wave reinforcement and wave cancellation. Note, the colour axis
% has been changed in order to see the weaker field areas. The 'max' figure
% on the plot refers to the raw plot data. Use caxis('auto') to see the full 
% range on the colorbar.
%
% Total power into the pair of dipoles is 100 Watts.
%
% Try changing the relative power and phase of the sources, see inside file.

close all
clc
help exdipoles

init;                              % Initialise global variables
arraypwr_config=100;               % Set array power to 100W
arrayeff_config=100;               % Set array efficiency to 100%
freq_config=1e9;                   % Set frequency (Hz)
lambda=3e8/(freq_config);          % Calculate wavelength (m)
dipole_config=lambda/2;            % Set the length of the dipole (m)

% *********  Array definition **********

single_element(0,-1*lambda,0,'dipole',0,0);  % Place dipole 1 at (x=0,y=-1*lambda,z=0) & Amp=0dB Phase=0Deg
single_element(0,+1*lambda,0,'dipole',0,0);  % Place dipole 2 at (x=0,y=+1*lambda,z=0) & Amp=0dB Phase=0Deg
yrot_array(90,1,2);    % Rotate the whole array (elements 1 to 2) 90deg around the y-axis
zrot_array(90,1,2);    % Rotate the whole array (elements 1 to 2) 90deg around the z-axis

% *****  Plot geometry and patterns ****

plot_geom3d(1,0);      % Plot 3D geometry with axis (uses standard figure1)
view([140,40]);        % Select view
plot_geom3d1(1,1,20);  % Plot 3D geometry with axis and element excitations in figure 20
view([140,40]);        % Select view
axis equal;

list_array(0);         % List the array x,y,z locations and excitations only
norm_array;            % Normalise the linear array excitations so they sum to unity
list_array(0);         % List the normalised excitations

calc_directivity(10,10); % Calculate the directivity dTheta=10, dPhi=10 Deg


% ******** Field slice plot *********

dBrange_config=40;  % Set dynamic range for field slice plots (dB)

xrng=1;      % Dimension of slice in local x-direction (m)
yrng=xrng;   % Dimension of slice in local y-direction (m)
xsteps=100;  % Number of steps in x
ysteps=100;  % Number of steps in y
xrot=0;        % Rotation about x-axis (deg)
yrot=0;        % Rotation about y-axis (deg)
zrot=0;        % Rotation about z-axis (deg)
xoff=0;                   % Offset in x (m)
yoff=0;                   % Offset in y (m)
zoff=0;                   % Offset in z (m)
polarisation='tot';     % Plot parameter (string)
normalise='no';         % Normalisation option (string)
units='vm';             % Display units (string)
fignum1=1;              % Figure number for plot in global coordinates (numeric)
fignum2=21;             % Figure number for plot in local/global coords as appropriate (numeric)

% Generate field-slice plots in global and local coordinates, fignum1 / fignum2   
[XGC,YGC,ZGC,XLC,YLC,ZLC,PlotData]=plot_field_slice1(xrng,xsteps,yrng,ysteps,xrot,yrot,zrot,...
   xoff,yoff,zoff,polarisation,normalise,units,fignum1,fignum2);    

% Fine tune the plots generated by plot_field_slice1

figure(fignum2);  % Select the figure for the slice-plot in local coordinates
warning off;      % Lots of grumbling from Matlab about color data and shading, but seems to work OK
shading flat;     % Set the shading to flat
caxis([0,2000]);  % Modify the color axis for better visualisation of lower field levels 
colorbar;         % Add the color scale

figure(fignum1);  % Select the figure for the slice plot in global coordinates.
                  % In this case figure1 which already has the 3D array geometry on it.
axis equal;
warning off;      % Lots of grumbling from Matlab about color data and shading, but seems to work OK
shading flat;
caxis([0,2000]);
colorbar;
title('3D Geometry and field slice (V/m)');
